@@ -30,8 +30,8 @@
 #include <gtk/gtk.h>
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
-#include <libxfce4panel/xfce-panel-plugin.h>
+#include <libxfce4ui/libxfce4ui.h>
+#include <libxfce4panel/libxfce4panel.h>
 
 
 #define BORDER 8
@@ -67,6 +67,9 @@ static char *errormessages[] = {
 typedef struct
 {
     gboolean use_label;
+    gboolean show_bars;
+    gboolean show_values;
+    gboolean colorize_values;
     gboolean auto_max;
     gulong   max[SUM];
     gint     update_interval;
@@ -81,6 +84,8 @@ typedef struct
 {
     GtkWidget  *box;
     GtkWidget  *label;
+    GtkWidget  *rcv_label;
+    GtkWidget  *sent_label;
     GtkWidget  *status[SUM];
 
     gulong     history[SUM][HISTSIZE_STORE];
@@ -108,9 +113,16 @@ typedef struct
     GtkWidget *max_entry[SUM];
     GtkBox    *max_hbox[SUM];
     
+    /* Bars and values */
+    GtkWidget *opt_present_data_hbox;
+    GtkWidget *opt_present_data_label;
+    GtkWidget *opt_present_data_combobox;
+    GtkWidget *opt_color_hbox[SUM];
+
     /* Color */
     GtkWidget *opt_button[SUM];
     GtkWidget *opt_da[SUM];
+    GtkWidget *opt_colorize_values;
     
 } t_monitor;
 
@@ -134,7 +146,10 @@ typedef struct
 static gboolean update_monitors(t_global_monitor *global)
 {
     char buffer[SUM+1][BUFSIZ];
+    char buffer_panel[SUM][BUFSIZ];
     gchar caption[BUFSIZ];
+    gchar received[BUFSIZ];
+    gchar sent[BUFSIZ];
     gulong net[SUM+1];
     gulong display[SUM+1], max;
     guint64 histcalculate;
@@ -218,21 +233,33 @@ static gboolean update_monitors(t_global_monitor *global)
         {
             temp = 0.0;
         }
-        gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(global->monitor->status[i]), temp);
 
-        format_with_thousandssep( buffer[i], BUFSIZ, display[i] / 1024.0, 2 );
+        if (global->monitor->options.show_bars)
+            gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(global->monitor->status[i]), temp);
+
+        format_byte_humanreadable( buffer[i], BUFSIZ, display[i], 2 );
+        format_byte_humanreadable( buffer_panel[i], BUFSIZ, display[i], 0 );
     }
     
-    format_with_thousandssep( buffer[TOT], BUFSIZ, (display[IN]+display[OUT])  / 1024.0, 2 );
+    format_byte_humanreadable( buffer[TOT], BUFSIZ, (display[IN]+display[OUT]), 2 );
     
     {
         char* ip = get_ip_address(&(global->monitor->data));
         g_snprintf(caption, sizeof(caption), 
                 _("<< %s >> (%s)\nAverage of last %d measures:\n"
-                    "Incoming: %s kByte/s\nOutgoing: %s kByte/s\nTotal: %s kByte/s"),
+                    "Incoming: %s/s\nOutgoing: %s/s\nTotal: %s/s"),
                     get_name(&(global->monitor->data)), ip ? ip : _("no IP address"),
                     HISTSIZE_CALCULATE, buffer[IN], buffer[OUT], buffer[TOT]);
         gtk_label_set_text(GTK_LABEL(global->tooltip_text), caption);
+
+        if (global->monitor->options.show_values)
+        {
+            g_snprintf(received, sizeof(received), "%s", buffer_panel[IN]);
+            gtk_label_set_text(GTK_LABEL(global->monitor->rcv_label), received);
+
+            g_snprintf(sent, sizeof(sent), "%s", buffer_panel[OUT]);
+            gtk_label_set_text(GTK_LABEL(global->monitor->sent_label), sent);
+        }
     }
 
     return TRUE;
@@ -285,11 +312,20 @@ static void monitor_set_orientation (XfcePanelPlugin *plugin, GtkOrientation ori
     global->monitor->label = gtk_label_new(global->monitor->options.label_text);
     gtk_widget_show(global->monitor->label);
 
+    global->monitor->rcv_label = gtk_label_new("");
+    gtk_label_set_width_chars(GTK_LABEL(global->monitor->rcv_label), 7);
+    gtk_misc_set_alignment(GTK_MISC(global->monitor->rcv_label), 1.0f, 0.5f);
+    gtk_widget_show(global->monitor->rcv_label);
+
     for (i = 0; i < SUM; i++)
     {
         global->monitor->status[i] = GTK_WIDGET(gtk_progress_bar_new());
     }
 
+    global->monitor->sent_label = gtk_label_new("");
+    gtk_label_set_width_chars(GTK_LABEL(global->monitor->sent_label), 7);
+    gtk_widget_show(global->monitor->sent_label);
+
     if (orientation == GTK_ORIENTATION_HORIZONTAL)
     {
         global->monitor->box = GTK_WIDGET(gtk_hbox_new(FALSE, 0));
@@ -298,6 +334,7 @@ static void monitor_set_orientation (XfcePanelPlugin *plugin, GtkOrientation ori
             gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(global->monitor->status[i]),
                     GTK_PROGRESS_BOTTOM_TO_TOP);
         }
+        gtk_misc_set_alignment(GTK_MISC(global->monitor->sent_label), 0.0f, 0.5f);
     }
     else
     {
@@ -307,13 +344,18 @@ static void monitor_set_orientation (XfcePanelPlugin *plugin, GtkOrientation ori
             gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(global->monitor->status[i]), 
                     GTK_PROGRESS_LEFT_TO_RIGHT);
         }
+        gtk_misc_set_alignment(GTK_MISC(global->monitor->sent_label), 1.0f, 0.5f);
     }
 
     gtk_box_pack_start(GTK_BOX(global->monitor->box),
                        GTK_WIDGET(global->monitor->label),
-                       FALSE, FALSE, 0);
+                       TRUE, FALSE, BORDER / 2);
 
-    gtk_container_set_border_width(GTK_CONTAINER(global->monitor->box), 2);
+    gtk_box_pack_start(GTK_BOX(global->monitor->box),
+                       GTK_WIDGET(global->monitor->rcv_label),
+                       TRUE, FALSE, BORDER / 2);
+
+    gtk_container_set_border_width(GTK_CONTAINER(global->monitor->box), BORDER / 2);
     gtk_widget_show(GTK_WIDGET(global->monitor->box));
 
     for (i = 0; i < SUM; i++)
@@ -333,6 +375,11 @@ static void monitor_set_orientation (XfcePanelPlugin *plugin, GtkOrientation ori
         gtk_box_pack_start(GTK_BOX(global->monitor->box),
                 GTK_WIDGET(global->monitor->status[i]), FALSE, FALSE, 0);
     }
+
+    gtk_box_pack_start(GTK_BOX(global->monitor->box),
+                     GTK_WIDGET(global->monitor->sent_label),
+                     TRUE, FALSE, BORDER / 2);
+
     gtk_box_pack_start(GTK_BOX(global->box),
                        GTK_WIDGET(global->monitor->box), FALSE, FALSE, 0);
 
@@ -346,8 +393,8 @@ static void monitor_set_orientation (XfcePanelPlugin *plugin, GtkOrientation ori
 /* ---------------------------------------------------------------------------------------------- */
 static gboolean tooltip_cb(GtkWidget *widget, gint x, gint y, gboolean keyboard, GtkTooltip *tooltip, t_global_monitor *global)
 {
-	gtk_tooltip_set_custom(tooltip, global->tooltip_text);
-	return TRUE;
+    gtk_tooltip_set_custom(tooltip, global->tooltip_text);
+    return TRUE;
 }
 
 /* ---------------------------------------------------------------------------------------------- */
@@ -396,6 +443,8 @@ static t_global_monitor * monitor_new(XfcePanelPlugin *plugin)
     global->monitor->options.network_device = g_strdup("");
     global->monitor->options.old_network_device = g_strdup("");
     global->monitor->options.use_label = TRUE;
+    global->monitor->options.show_values = FALSE;
+    global->monitor->options.show_bars = TRUE;
     global->monitor->options.auto_max = TRUE;
     global->monitor->options.update_interval = UPDATE_TIMEOUT;
     
@@ -427,9 +476,17 @@ static void setup_monitor(t_global_monitor *global, gboolean supress_warnings)
     gtk_widget_hide(global->monitor->label);
     gtk_label_set_text(GTK_LABEL(global->monitor->label),
             global->monitor->options.label_text);
-
+    gtk_widget_hide(global->monitor->rcv_label);
     for (i = 0; i < SUM; i++)
+      gtk_widget_hide(global->monitor->status[i]);
+    gtk_widget_hide(global->monitor->sent_label);
+
+    if (global->monitor->options.show_bars)
     {
+      for (i = 0; i < SUM; i++)
+      {
+        gtk_widget_show(global->monitor->status[i]);
+
         gtk_widget_modify_bg(GTK_WIDGET(global->monitor->status[i]),
                              GTK_STATE_PRELIGHT,
                              &global->monitor->options.color[i]);
@@ -449,18 +506,31 @@ static void setup_monitor(t_global_monitor *global, gboolean supress_warnings)
         {
             global->monitor->net_max[i] = global->monitor->options.max[i];
         }
+      }
     }
 
     gtk_widget_show(GTK_WIDGET(global->monitor->box));
+
     if (global->monitor->options.use_label)
     {
         gtk_widget_show(global->monitor->label);
     }
-    
+
+    if (global->monitor->options.show_values)
+    {
+        gtk_widget_modify_fg(global->monitor->rcv_label, GTK_STATE_NORMAL,
+                             (global->monitor->options.colorize_values ? &global->monitor->options.color[IN] : NULL));
+        gtk_widget_modify_fg(global->monitor->sent_label, GTK_STATE_NORMAL,
+                             (global->monitor->options.colorize_values ? &global->monitor->options.color[OUT] : NULL));
+        gtk_widget_show(global->monitor->rcv_label);
+        gtk_widget_show(global->monitor->sent_label);
+    }
+
     if (!init_netload( &(global->monitor->data), global->monitor->options.network_device)
             && !supress_warnings)
     {
-        xfce_err (_("%s: Error in initalizing:\n%s"),
+        xfce_dialog_show_error (NULL, NULL,
+        _("%s: Error in initializing:\n%s"),
             _(APP_NAME),
             _(errormessages[
                 global->monitor->data.errorcode == 0 
@@ -494,8 +564,13 @@ static void monitor_read_config(XfcePanelPlugin *plugin, t_global_monitor *globa
 
     if (!rc)
         return;
-    
+
     global->monitor->options.use_label = xfce_rc_read_bool_entry (rc, "Use_Label", TRUE);
+    global->monitor->options.show_values = xfce_rc_read_bool_entry (rc, "Show_Values", FALSE);
+    global->monitor->options.show_bars = xfce_rc_read_bool_entry (rc, "Show_Bars", TRUE);
+    global->monitor->options.colorize_values = xfce_rc_read_bool_entry (rc, "Colorize_Values", FALSE);
+    if (!global->monitor->options.show_bars && !global->monitor->options.show_values)
+        global->monitor->options.show_bars = TRUE;
 
     if ((value = xfce_rc_read_entry (rc, "Color_In", NULL)) != NULL)
     {
@@ -513,6 +588,7 @@ static void monitor_read_config(XfcePanelPlugin *plugin, t_global_monitor *globa
             g_free(global->monitor->options.label_text);
         global->monitor->options.label_text = g_strdup(value);
     }
+
     if ((value = xfce_rc_read_entry (rc, "Network_Device", NULL)) && *value)
     {
         if (global->monitor->options.network_device)
@@ -555,8 +631,11 @@ static void monitor_write_config(XfcePanelPlugin *plugin, t_global_monitor *glob
 
     if (!rc)
         return;
-    
+
     xfce_rc_write_bool_entry (rc, "Use_Label", global->monitor->options.use_label);
+    xfce_rc_write_bool_entry (rc, "Show_Values", global->monitor->options.show_values);
+    xfce_rc_write_bool_entry (rc, "Show_Bars", global->monitor->options.show_bars);
+    xfce_rc_write_bool_entry (rc, "Colorize_Values", global->monitor->options.colorize_values);
 
     g_snprintf(value, 8, "#%02X%02X%02X",
                (guint)global->monitor->options.color[IN].red >> 8,
@@ -619,7 +698,7 @@ static gboolean monitor_set_size(XfcePanelPlugin *plugin, int size, t_global_mon
 static void monitor_apply_options(t_global_monitor *global)
 {
     gint i;
-    
+
     if (global->monitor->options.label_text)
     {
         g_free(global->monitor->options.label_text);
@@ -629,7 +708,6 @@ static void monitor_apply_options(t_global_monitor *global)
         g_strdup(gtk_entry_get_text(GTK_ENTRY(global->monitor->opt_entry)));
     setup_monitor(global, FALSE);
 
-
     if (global->monitor->options.network_device)
     {
         g_free(global->monitor->options.network_device);
@@ -713,6 +791,21 @@ static void label_toggled(GtkWidget *check_button, t_global_monitor *global)
     PRINT_DBG("label_toggled");
 }
 
+/* ---------------------------------------------------------------------------------------------- */
+static void present_data_combobox_changed(GtkWidget *combobox, t_global_monitor *global)
+{
+    gint option = gtk_combo_box_get_active(GTK_COMBO_BOX(combobox));
+    g_assert(option >= 0 && option <= 2);
+    
+    global->monitor->options.show_bars = (option == 0 || option == 2);
+    global->monitor->options.show_values = (option == 1 || option == 2);
+    
+    gtk_widget_set_sensitive(GTK_WIDGET(global->monitor->opt_colorize_values),
+                             global->monitor->options.show_values);
+
+    setup_monitor(global, FALSE);
+    PRINT_DBG("present_data_combobox_changed");
+}
 
 /* ---------------------------------------------------------------------------------------------- */
 static void max_label_toggled(GtkWidget *check_button, t_global_monitor *global)
@@ -738,6 +831,17 @@ static void max_label_toggled(GtkWidget *check_button, t_global_monitor *global)
 }
 
 
+/* ---------------------------------------------------------------------------------------------- */
+static void colorize_values_toggled(GtkWidget *check_button, t_global_monitor *global)
+{
+    global->monitor->options.colorize_values = !global->monitor->options.colorize_values;
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(global->monitor->opt_colorize_values),
+                                 global->monitor->options.colorize_values);
+    setup_monitor(global, FALSE);
+    PRINT_DBG("colorize_values_toggled");
+}
+
+
 /* ---------------------------------------------------------------------------------------------- */
 static gboolean expose_event_cb(GtkWidget *widget, GdkEventExpose *event)
 {
@@ -826,17 +930,17 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
     GtkWidget        *update_label, *update_unit_label;
     GtkWidget        *color_label[SUM];
     GtkWidget        *align;
-    GtkBox           *color_hbox[SUM];
+    gint             present_data_active;
     GtkSizeGroup     *sg;
     gint             i;
     gchar            buffer[BUFSIZ];
     gchar            *color_text[] = { 
-                        N_("Bar color (incoming):"), 
-                        N_("Bar color (outgoing):") 
+                        N_("Bar color (i_ncoming):"), 
+                        N_("Bar color (_outgoing):") 
                      };
     gchar            *maximum_text_label[] = {
-                        N_("Maximum (incoming):"),
-                        N_("Maximum (outgoing):")
+                        N_("Maximum (inco_ming):"),
+                        N_("Maximum (o_utgoing):")
                      };
     
     xfce_panel_plugin_block_menu (plugin);
@@ -870,7 +974,7 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
     gtk_widget_show(GTK_WIDGET(global->monitor->opt_hbox));
     
     global->monitor->opt_use_label =
-        gtk_check_button_new_with_mnemonic(_("Text to display:"));
+        gtk_check_button_new_with_mnemonic(_("_Text to display:"));
     gtk_widget_show(global->monitor->opt_use_label);
     gtk_box_pack_start(GTK_BOX(global->monitor->opt_hbox),
                        GTK_WIDGET(global->monitor->opt_use_label),
@@ -895,19 +999,21 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
                                  global->monitor->options.use_label);
     gtk_widget_set_sensitive(GTK_WIDGET(global->monitor->opt_entry),
                              global->monitor->options.use_label);
-                             
+
     /* Network device */
     net_hbox = GTK_BOX(gtk_hbox_new(FALSE, 5));
     gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox),
                         GTK_WIDGET(net_hbox), FALSE, FALSE, 0);
 
-    device_label = gtk_label_new(_("Network device:"));
+    device_label = gtk_label_new_with_mnemonic(_("Network _device:"));
     gtk_misc_set_alignment(GTK_MISC(device_label), 0, 0.5);
     gtk_widget_show(GTK_WIDGET(device_label));
     gtk_box_pack_start(GTK_BOX(net_hbox), GTK_WIDGET(device_label),
                        FALSE, FALSE, 0);
 
     global->monitor->net_entry = gtk_entry_new();
+    gtk_label_set_mnemonic_widget(GTK_LABEL(device_label),
+                                  global->monitor->net_entry);
     gtk_entry_set_max_length(GTK_ENTRY(global->monitor->net_entry),
                              MAX_LENGTH);
     gtk_entry_set_text(GTK_ENTRY(global->monitor->net_entry),
@@ -927,11 +1033,13 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
     gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox),
                         GTK_WIDGET(update_hbox), FALSE, FALSE, 0);
     
-    update_label = gtk_label_new(_("Update interval:"));
+    update_label = gtk_label_new_with_mnemonic(_("Update _interval:"));
     gtk_misc_set_alignment(GTK_MISC(update_label), 0, 0.5);
     gtk_box_pack_start(GTK_BOX(update_hbox), GTK_WIDGET(update_label), FALSE, FALSE, 0);
-    
+
     global->monitor->update_spinner = gtk_spin_button_new_with_range (0.1, 10.0, 0.05);
+    gtk_label_set_mnemonic_widget(GTK_LABEL(update_label),
+                                  global->monitor->update_spinner);
     gtk_spin_button_set_digits( GTK_SPIN_BUTTON(global->monitor->update_spinner), 2 );
     gtk_spin_button_set_value( GTK_SPIN_BUTTON(global->monitor->update_spinner), 
             global->monitor->options.update_interval / 1000.0 );
@@ -951,7 +1059,7 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
     gtk_widget_show(sep1);
     
     global->monitor->max_use_label = 
-                gtk_check_button_new_with_mnemonic(_("Automatic maximum"));
+                gtk_check_button_new_with_mnemonic(_("_Automatic maximum"));
     gtk_widget_show(global->monitor->max_use_label);
     gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox),
                 GTK_WIDGET(global->monitor->max_use_label), FALSE, FALSE, 0);
@@ -966,12 +1074,14 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
         gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox), 
                     GTK_WIDGET(global->monitor->max_hbox[i]), FALSE, FALSE, 0);
         
-        max_label[i] = gtk_label_new(_(maximum_text_label[i]));
+        max_label[i] = gtk_label_new_with_mnemonic(_(maximum_text_label[i]));
         gtk_misc_set_alignment(GTK_MISC(max_label[i]), 0, 0.5);
         gtk_widget_show(GTK_WIDGET(max_label[i]));
         gtk_box_pack_start(GTK_BOX(global->monitor->max_hbox[i]), GTK_WIDGET(max_label[i]), FALSE, FALSE, 0);
         
         global->monitor->max_entry[i] = gtk_entry_new();
+        gtk_label_set_mnemonic_widget(GTK_LABEL(max_label[i]),
+                                      global->monitor->max_entry[i]);
         gtk_entry_set_max_length(GTK_ENTRY(global->monitor->max_entry[i]), MAX_LENGTH);
         
         g_snprintf( buffer, BUFSIZ, "%.2f", global->monitor->options.max[i] / 1024.0 );
@@ -983,7 +1093,7 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
         gtk_box_pack_start(GTK_BOX(global->monitor->max_hbox[i]), GTK_WIDGET(global->monitor->max_entry[i]),
                        FALSE, FALSE, 0);
         
-        unit_label[i] = gtk_label_new(_("kByte/s"));
+        unit_label[i] = gtk_label_new(_("KiB/s"));
         gtk_box_pack_start(GTK_BOX(global->monitor->max_hbox[i]), GTK_WIDGET(unit_label[i]), FALSE, FALSE, 0);
         
         gtk_size_group_add_widget(sg, max_label[i]);
@@ -1002,21 +1112,56 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
     gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox), GTK_WIDGET(sep2), FALSE, FALSE, 0);
     gtk_widget_show(sep2);
     
+    /* Show bars and values */
+    global->monitor->opt_present_data_hbox = GTK_WIDGET(gtk_hbox_new(FALSE, 5));
+    gtk_widget_show(global->monitor->opt_present_data_hbox);
+    gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox),
+                       GTK_WIDGET(global->monitor->opt_present_data_hbox), FALSE, FALSE, 0);
+
+    global->monitor->opt_present_data_label = gtk_label_new_with_mnemonic(_("_Present data as:"));
+    gtk_misc_set_alignment(GTK_MISC(global->monitor->opt_present_data_label), 0, 0.5);
+    gtk_widget_show(global->monitor->opt_present_data_label);
+    gtk_box_pack_start(GTK_BOX(global->monitor->opt_present_data_hbox),
+                       global->monitor->opt_present_data_label, FALSE, FALSE, 0);
+
+    global->monitor->opt_present_data_combobox = gtk_combo_box_new_text();
+    gtk_label_set_mnemonic_widget(GTK_LABEL(global->monitor->opt_present_data_label),
+                                  global->monitor->opt_present_data_combobox);
+    gtk_combo_box_append_text(GTK_COMBO_BOX(global->monitor->opt_present_data_combobox), _("Bars"));
+    gtk_combo_box_append_text(GTK_COMBO_BOX(global->monitor->opt_present_data_combobox), _("Values"));
+    gtk_combo_box_append_text(GTK_COMBO_BOX(global->monitor->opt_present_data_combobox), _("Bars and values"));
+
+    if(global->monitor->options.show_values)
+        if(global->monitor->options.show_bars)
+            present_data_active = 2;
+        else
+            present_data_active = 1;
+    else
+        present_data_active = 0;
+    gtk_combo_box_set_active(GTK_COMBO_BOX(global->monitor->opt_present_data_combobox), present_data_active);
+
+    gtk_widget_show(global->monitor->opt_present_data_combobox);
+    gtk_box_pack_start(GTK_BOX(global->monitor->opt_present_data_hbox),
+                       global->monitor->opt_present_data_combobox, FALSE, FALSE, 0);
+    gtk_size_group_add_widget(sg, global->monitor->opt_present_data_label);
+
     /* Color 1 */
     for (i = 0; i < SUM; i++)
     {
-        color_hbox[i] = GTK_BOX(gtk_hbox_new(FALSE, 5));
-        gtk_widget_show(GTK_WIDGET(color_hbox[i]));
+        global->monitor->opt_color_hbox[i] = gtk_hbox_new(FALSE, 5);
+        gtk_widget_show(GTK_WIDGET(global->monitor->opt_color_hbox[i]));
         gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox),
-                GTK_WIDGET(color_hbox[i]), FALSE, FALSE, 0);
+                GTK_WIDGET(global->monitor->opt_color_hbox[i]), FALSE, FALSE, 0);
 
-        color_label[i] = gtk_label_new(_(color_text[i]));
+        color_label[i] = gtk_label_new_with_mnemonic(_(color_text[i]));
         gtk_misc_set_alignment(GTK_MISC(color_label[i]), 0, 0.5);
         gtk_widget_show(GTK_WIDGET(color_label[i]));
-        gtk_box_pack_start(GTK_BOX(color_hbox[i]), GTK_WIDGET(color_label[i]),
+        gtk_box_pack_start(GTK_BOX(global->monitor->opt_color_hbox[i]), GTK_WIDGET(color_label[i]),
                 FALSE, FALSE, 0);
 
         global->monitor->opt_button[i] = gtk_button_new();
+        gtk_label_set_mnemonic_widget(GTK_LABEL(color_label[i]),
+                                      global->monitor->opt_button[i]);
         global->monitor->opt_da[i] = gtk_drawing_area_new();
         
         gtk_widget_modify_bg(global->monitor->opt_da[i], GTK_STATE_NORMAL,
@@ -1026,14 +1171,23 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
                 global->monitor->opt_da[i]);
         gtk_widget_show(GTK_WIDGET(global->monitor->opt_button[i]));
         gtk_widget_show(GTK_WIDGET(global->monitor->opt_da[i]));
-        gtk_box_pack_start(GTK_BOX(color_hbox[i]),
+        gtk_box_pack_start(GTK_BOX(global->monitor->opt_color_hbox[i]),
                 GTK_WIDGET(global->monitor->opt_button[i]),
                 FALSE, FALSE, 0);
 
         gtk_size_group_add_widget(sg, color_label[i]);
 
     }
-    
+    global->monitor->opt_colorize_values =
+        gtk_check_button_new_with_mnemonic(_("_Colorize values"));
+    gtk_widget_show(global->monitor->opt_colorize_values);
+    gtk_box_pack_start(GTK_BOX(global->monitor->opt_vbox),
+                       GTK_WIDGET(global->monitor->opt_colorize_values), FALSE, FALSE, 0);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(global->monitor->opt_colorize_values),
+                                 global->monitor->options.colorize_values);
+    gtk_widget_set_sensitive(GTK_WIDGET(global->monitor->opt_colorize_values),
+                             global->monitor->options.show_values);
+
     gtk_box_pack_start(GTK_BOX(vbox),
                 GTK_WIDGET(global->monitor->opt_vbox),
                 FALSE, FALSE, 0);
@@ -1042,11 +1196,13 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
     gtk_widget_set_size_request(align, 5, 5);
     gtk_widget_show(GTK_WIDGET(align));
     gtk_box_pack_start(GTK_BOX(vbox), GTK_WIDGET(align), FALSE, FALSE, 0);
-    
+
     gtk_box_pack_start( GTK_BOX(global_vbox), GTK_WIDGET(vbox), FALSE, FALSE, 0);
     
     g_signal_connect(GTK_WIDGET(global->monitor->max_use_label), "toggled",
             G_CALLBACK(max_label_toggled), global);
+    g_signal_connect(GTK_WIDGET(global->monitor->opt_colorize_values), "toggled",
+            G_CALLBACK(colorize_values_toggled), global);
     g_signal_connect(GTK_WIDGET(global->monitor->opt_da[0]), "expose_event",
             G_CALLBACK(expose_event_cb), NULL);
     g_signal_connect(GTK_WIDGET(global->monitor->opt_da[1]), "expose_event",
@@ -1059,6 +1215,8 @@ static void monitor_create_options(XfcePanelPlugin *plugin, t_global_monitor *gl
             G_CALLBACK(label_toggled), global);
     g_signal_connect(GTK_WIDGET(global->monitor->opt_entry), "activate",
             G_CALLBACK(label_changed), global);
+    g_signal_connect(GTK_WIDGET(global->monitor->opt_present_data_combobox), "changed",
+            G_CALLBACK(present_data_combobox_changed), global);
     g_signal_connect(GTK_WIDGET(global->monitor->net_entry), "activate",
             G_CALLBACK(network_changed), global);
 
@@ -1089,7 +1247,7 @@ static void netload_construct (XfcePanelPlugin *plugin)
     g_signal_connect (plugin, "orientation-changed", G_CALLBACK (monitor_set_orientation), global);
     
     gtk_container_add(GTK_CONTAINER(plugin), global->ebox);
-	
+    
     run_update( global );
 }
 
